/*!
  \file
  \brief t@C폜

  \author Satofumi KAMIMURA

  $Id$

  \todo MSC p̒s
*/

#include "RemoveFile.h"
#include "DetectOS.h"
#ifndef MSC
#include <unistd.h>
#else
#include <windows.h>
#endif

void beego::removeFile(const char *file) {

#ifndef WINDOWS_OS
  unlink(file);
#else
  DeleteFileA(file);
#endif
}
